# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class BouncedRecipientDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'user_id': 'str',
        'sent_email_id': 'str',
        'recipient': 'str',
        'diagnostic_code': 'str',
        'action': 'str',
        'bounce_type': 'str',
        'status': 'str',
        'created_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'userId',
        'sent_email_id': 'sentEmailId',
        'recipient': 'recipient',
        'diagnostic_code': 'diagnosticCode',
        'action': 'action',
        'bounce_type': 'bounceType',
        'status': 'status',
        'created_at': 'createdAt'
    }

    def __init__(self, id=None, user_id=None, sent_email_id=None, recipient=None, diagnostic_code=None, action=None, bounce_type=None, status=None, created_at=None, local_vars_configuration=None):  # noqa: E501
        """BouncedRecipientDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._user_id = None
        self._sent_email_id = None
        self._recipient = None
        self._diagnostic_code = None
        self._action = None
        self._bounce_type = None
        self._status = None
        self._created_at = None
        self.discriminator = None

        self.id = id
        self.user_id = user_id
        self.sent_email_id = sent_email_id
        self.recipient = recipient
        self.diagnostic_code = diagnostic_code
        self.action = action
        self.bounce_type = bounce_type
        self.status = status
        self.created_at = created_at

    @property
    def id(self):
        """Gets the id of this BouncedRecipientDto.  # noqa: E501


        :return: The id of this BouncedRecipientDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BouncedRecipientDto.


        :param id: The id of this BouncedRecipientDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this BouncedRecipientDto.  # noqa: E501


        :return: The user_id of this BouncedRecipientDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this BouncedRecipientDto.


        :param user_id: The user_id of this BouncedRecipientDto.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def sent_email_id(self):
        """Gets the sent_email_id of this BouncedRecipientDto.  # noqa: E501


        :return: The sent_email_id of this BouncedRecipientDto.  # noqa: E501
        :rtype: str
        """
        return self._sent_email_id

    @sent_email_id.setter
    def sent_email_id(self, sent_email_id):
        """Sets the sent_email_id of this BouncedRecipientDto.


        :param sent_email_id: The sent_email_id of this BouncedRecipientDto.  # noqa: E501
        :type: str
        """

        self._sent_email_id = sent_email_id

    @property
    def recipient(self):
        """Gets the recipient of this BouncedRecipientDto.  # noqa: E501


        :return: The recipient of this BouncedRecipientDto.  # noqa: E501
        :rtype: str
        """
        return self._recipient

    @recipient.setter
    def recipient(self, recipient):
        """Sets the recipient of this BouncedRecipientDto.


        :param recipient: The recipient of this BouncedRecipientDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and recipient is None:  # noqa: E501
            raise ValueError("Invalid value for `recipient`, must not be `None`")  # noqa: E501

        self._recipient = recipient

    @property
    def diagnostic_code(self):
        """Gets the diagnostic_code of this BouncedRecipientDto.  # noqa: E501


        :return: The diagnostic_code of this BouncedRecipientDto.  # noqa: E501
        :rtype: str
        """
        return self._diagnostic_code

    @diagnostic_code.setter
    def diagnostic_code(self, diagnostic_code):
        """Sets the diagnostic_code of this BouncedRecipientDto.


        :param diagnostic_code: The diagnostic_code of this BouncedRecipientDto.  # noqa: E501
        :type: str
        """

        self._diagnostic_code = diagnostic_code

    @property
    def action(self):
        """Gets the action of this BouncedRecipientDto.  # noqa: E501


        :return: The action of this BouncedRecipientDto.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this BouncedRecipientDto.


        :param action: The action of this BouncedRecipientDto.  # noqa: E501
        :type: str
        """

        self._action = action

    @property
    def bounce_type(self):
        """Gets the bounce_type of this BouncedRecipientDto.  # noqa: E501


        :return: The bounce_type of this BouncedRecipientDto.  # noqa: E501
        :rtype: str
        """
        return self._bounce_type

    @bounce_type.setter
    def bounce_type(self, bounce_type):
        """Sets the bounce_type of this BouncedRecipientDto.


        :param bounce_type: The bounce_type of this BouncedRecipientDto.  # noqa: E501
        :type: str
        """

        self._bounce_type = bounce_type

    @property
    def status(self):
        """Gets the status of this BouncedRecipientDto.  # noqa: E501


        :return: The status of this BouncedRecipientDto.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this BouncedRecipientDto.


        :param status: The status of this BouncedRecipientDto.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def created_at(self):
        """Gets the created_at of this BouncedRecipientDto.  # noqa: E501


        :return: The created_at of this BouncedRecipientDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this BouncedRecipientDto.


        :param created_at: The created_at of this BouncedRecipientDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BouncedRecipientDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BouncedRecipientDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class AttachmentMetaData(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'content_type': 'str',
        'content_length': 'int',
        'id': 'str',
        'content_id': 'str'
    }

    attribute_map = {
        'name': 'name',
        'content_type': 'contentType',
        'content_length': 'contentLength',
        'id': 'id',
        'content_id': 'contentId'
    }

    def __init__(self, name=None, content_type=None, content_length=None, id=None, content_id=None, local_vars_configuration=None):  # noqa: E501
        """AttachmentMetaData - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._content_type = None
        self._content_length = None
        self._id = None
        self._content_id = None
        self.discriminator = None

        self.name = name
        self.content_type = content_type
        self.content_length = content_length
        self.id = id
        self.content_id = content_id

    @property
    def name(self):
        """Gets the name of this AttachmentMetaData.  # noqa: E501

        Name of attachment if given  # noqa: E501

        :return: The name of this AttachmentMetaData.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AttachmentMetaData.

        Name of attachment if given  # noqa: E501

        :param name: The name of this AttachmentMetaData.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def content_type(self):
        """Gets the content_type of this AttachmentMetaData.  # noqa: E501

        Content type of attachment such as `image/png`  # noqa: E501

        :return: The content_type of this AttachmentMetaData.  # noqa: E501
        :rtype: str
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """Sets the content_type of this AttachmentMetaData.

        Content type of attachment such as `image/png`  # noqa: E501

        :param content_type: The content_type of this AttachmentMetaData.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and content_type is None:  # noqa: E501
            raise ValueError("Invalid value for `content_type`, must not be `None`")  # noqa: E501

        self._content_type = content_type

    @property
    def content_length(self):
        """Gets the content_length of this AttachmentMetaData.  # noqa: E501

        Size of attachment in bytes  # noqa: E501

        :return: The content_length of this AttachmentMetaData.  # noqa: E501
        :rtype: int
        """
        return self._content_length

    @content_length.setter
    def content_length(self, content_length):
        """Sets the content_length of this AttachmentMetaData.

        Size of attachment in bytes  # noqa: E501

        :param content_length: The content_length of this AttachmentMetaData.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and content_length is None:  # noqa: E501
            raise ValueError("Invalid value for `content_length`, must not be `None`")  # noqa: E501

        self._content_length = content_length

    @property
    def id(self):
        """Gets the id of this AttachmentMetaData.  # noqa: E501

        ID of attachment. Can be used to with attachment controller endpoints to download attachment or with sending methods to attach to an email.  # noqa: E501

        :return: The id of this AttachmentMetaData.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AttachmentMetaData.

        ID of attachment. Can be used to with attachment controller endpoints to download attachment or with sending methods to attach to an email.  # noqa: E501

        :param id: The id of this AttachmentMetaData.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def content_id(self):
        """Gets the content_id of this AttachmentMetaData.  # noqa: E501

        CID of attachment  # noqa: E501

        :return: The content_id of this AttachmentMetaData.  # noqa: E501
        :rtype: str
        """
        return self._content_id

    @content_id.setter
    def content_id(self, content_id):
        """Sets the content_id of this AttachmentMetaData.

        CID of attachment  # noqa: E501

        :param content_id: The content_id of this AttachmentMetaData.  # noqa: E501
        :type: str
        """

        self._content_id = content_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AttachmentMetaData):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AttachmentMetaData):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class EmailPreview(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'inbox_id': 'str',
        'domain_id': 'str',
        'subject': 'str',
        'to': 'list[str]',
        '_from': 'str',
        'bcc': 'list[str]',
        'cc': 'list[str]',
        'created_at': 'datetime',
        'read': 'bool',
        'attachments': 'list[str]',
        'thread_id': 'str',
        'message_id': 'str',
        'in_reply_to': 'str',
        'sender': 'Sender',
        'recipients': 'EmailRecipients',
        'favourite': 'bool',
        'body_part_content_types': 'list[str]',
        'plus_address': 'str',
        'size_bytes': 'int'
    }

    attribute_map = {
        'id': 'id',
        'inbox_id': 'inboxId',
        'domain_id': 'domainId',
        'subject': 'subject',
        'to': 'to',
        '_from': 'from',
        'bcc': 'bcc',
        'cc': 'cc',
        'created_at': 'createdAt',
        'read': 'read',
        'attachments': 'attachments',
        'thread_id': 'threadId',
        'message_id': 'messageId',
        'in_reply_to': 'inReplyTo',
        'sender': 'sender',
        'recipients': 'recipients',
        'favourite': 'favourite',
        'body_part_content_types': 'bodyPartContentTypes',
        'plus_address': 'plusAddress',
        'size_bytes': 'sizeBytes'
    }

    def __init__(self, id=None, inbox_id=None, domain_id=None, subject=None, to=None, _from=None, bcc=None, cc=None, created_at=None, read=None, attachments=None, thread_id=None, message_id=None, in_reply_to=None, sender=None, recipients=None, favourite=None, body_part_content_types=None, plus_address=None, size_bytes=None, local_vars_configuration=None):  # noqa: E501
        """EmailPreview - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._inbox_id = None
        self._domain_id = None
        self._subject = None
        self._to = None
        self.__from = None
        self._bcc = None
        self._cc = None
        self._created_at = None
        self._read = None
        self._attachments = None
        self._thread_id = None
        self._message_id = None
        self._in_reply_to = None
        self._sender = None
        self._recipients = None
        self._favourite = None
        self._body_part_content_types = None
        self._plus_address = None
        self._size_bytes = None
        self.discriminator = None

        self.id = id
        self.inbox_id = inbox_id
        self.domain_id = domain_id
        self.subject = subject
        self.to = to
        self._from = _from
        self.bcc = bcc
        self.cc = cc
        self.created_at = created_at
        self.read = read
        self.attachments = attachments
        self.thread_id = thread_id
        self.message_id = message_id
        self.in_reply_to = in_reply_to
        self.sender = sender
        self.recipients = recipients
        self.favourite = favourite
        self.body_part_content_types = body_part_content_types
        self.plus_address = plus_address
        self.size_bytes = size_bytes

    @property
    def id(self):
        """Gets the id of this EmailPreview.  # noqa: E501

        ID of the email entity  # noqa: E501

        :return: The id of this EmailPreview.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this EmailPreview.

        ID of the email entity  # noqa: E501

        :param id: The id of this EmailPreview.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def inbox_id(self):
        """Gets the inbox_id of this EmailPreview.  # noqa: E501

        ID of the inbox that received the email  # noqa: E501

        :return: The inbox_id of this EmailPreview.  # noqa: E501
        :rtype: str
        """
        return self._inbox_id

    @inbox_id.setter
    def inbox_id(self, inbox_id):
        """Sets the inbox_id of this EmailPreview.

        ID of the inbox that received the email  # noqa: E501

        :param inbox_id: The inbox_id of this EmailPreview.  # noqa: E501
        :type: str
        """

        self._inbox_id = inbox_id

    @property
    def domain_id(self):
        """Gets the domain_id of this EmailPreview.  # noqa: E501

        ID of the domain that received the email  # noqa: E501

        :return: The domain_id of this EmailPreview.  # noqa: E501
        :rtype: str
        """
        return self._domain_id

    @domain_id.setter
    def domain_id(self, domain_id):
        """Sets the domain_id of this EmailPreview.

        ID of the domain that received the email  # noqa: E501

        :param domain_id: The domain_id of this EmailPreview.  # noqa: E501
        :type: str
        """

        self._domain_id = domain_id

    @property
    def subject(self):
        """Gets the subject of this EmailPreview.  # noqa: E501

        The subject line of the email message as specified by SMTP subject header  # noqa: E501

        :return: The subject of this EmailPreview.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this EmailPreview.

        The subject line of the email message as specified by SMTP subject header  # noqa: E501

        :param subject: The subject of this EmailPreview.  # noqa: E501
        :type: str
        """

        self._subject = subject

    @property
    def to(self):
        """Gets the to of this EmailPreview.  # noqa: E501

        List of `To` recipient email addresses that the email was addressed to. See recipients object for names.  # noqa: E501

        :return: The to of this EmailPreview.  # noqa: E501
        :rtype: list[str]
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this EmailPreview.

        List of `To` recipient email addresses that the email was addressed to. See recipients object for names.  # noqa: E501

        :param to: The to of this EmailPreview.  # noqa: E501
        :type: list[str]
        """

        self._to = to

    @property
    def _from(self):
        """Gets the _from of this EmailPreview.  # noqa: E501

        Who the email was sent from. An email address - see fromName for the sender name.  # noqa: E501

        :return: The _from of this EmailPreview.  # noqa: E501
        :rtype: str
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this EmailPreview.

        Who the email was sent from. An email address - see fromName for the sender name.  # noqa: E501

        :param _from: The _from of this EmailPreview.  # noqa: E501
        :type: str
        """

        self.__from = _from

    @property
    def bcc(self):
        """Gets the bcc of this EmailPreview.  # noqa: E501

        List of `BCC` recipients email addresses that the email was addressed to. See recipients object for names.  # noqa: E501

        :return: The bcc of this EmailPreview.  # noqa: E501
        :rtype: list[str]
        """
        return self._bcc

    @bcc.setter
    def bcc(self, bcc):
        """Sets the bcc of this EmailPreview.

        List of `BCC` recipients email addresses that the email was addressed to. See recipients object for names.  # noqa: E501

        :param bcc: The bcc of this EmailPreview.  # noqa: E501
        :type: list[str]
        """

        self._bcc = bcc

    @property
    def cc(self):
        """Gets the cc of this EmailPreview.  # noqa: E501

        List of `CC` recipients email addresses that the email was addressed to. See recipients object for names.  # noqa: E501

        :return: The cc of this EmailPreview.  # noqa: E501
        :rtype: list[str]
        """
        return self._cc

    @cc.setter
    def cc(self, cc):
        """Sets the cc of this EmailPreview.

        List of `CC` recipients email addresses that the email was addressed to. See recipients object for names.  # noqa: E501

        :param cc: The cc of this EmailPreview.  # noqa: E501
        :type: list[str]
        """

        self._cc = cc

    @property
    def created_at(self):
        """Gets the created_at of this EmailPreview.  # noqa: E501

        When was the email received by MailSlurp  # noqa: E501

        :return: The created_at of this EmailPreview.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this EmailPreview.

        When was the email received by MailSlurp  # noqa: E501

        :param created_at: The created_at of this EmailPreview.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def read(self):
        """Gets the read of this EmailPreview.  # noqa: E501

        Read flag. Has the email ever been viewed in the dashboard or fetched via the API with a hydrated body? If so the email is marked as read. Paginated results do not affect read status. Read status is different to email opened event as it depends on your own account accessing the email. Email opened is determined by tracking pixels sent to other uses if enable during sending. You can listened for both email read and email opened events using webhooks.  # noqa: E501

        :return: The read of this EmailPreview.  # noqa: E501
        :rtype: bool
        """
        return self._read

    @read.setter
    def read(self, read):
        """Sets the read of this EmailPreview.

        Read flag. Has the email ever been viewed in the dashboard or fetched via the API with a hydrated body? If so the email is marked as read. Paginated results do not affect read status. Read status is different to email opened event as it depends on your own account accessing the email. Email opened is determined by tracking pixels sent to other uses if enable during sending. You can listened for both email read and email opened events using webhooks.  # noqa: E501

        :param read: The read of this EmailPreview.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and read is None:  # noqa: E501
            raise ValueError("Invalid value for `read`, must not be `None`")  # noqa: E501

        self._read = read

    @property
    def attachments(self):
        """Gets the attachments of this EmailPreview.  # noqa: E501

        List of IDs of attachments found in the email. Use these IDs with the Inbox and Email Controllers to download attachments and attachment meta data such as filesize, name, extension.  # noqa: E501

        :return: The attachments of this EmailPreview.  # noqa: E501
        :rtype: list[str]
        """
        return self._attachments

    @attachments.setter
    def attachments(self, attachments):
        """Sets the attachments of this EmailPreview.

        List of IDs of attachments found in the email. Use these IDs with the Inbox and Email Controllers to download attachments and attachment meta data such as filesize, name, extension.  # noqa: E501

        :param attachments: The attachments of this EmailPreview.  # noqa: E501
        :type: list[str]
        """

        self._attachments = attachments

    @property
    def thread_id(self):
        """Gets the thread_id of this EmailPreview.  # noqa: E501

        MailSlurp thread ID for email chain that enables lookup for In-Reply-To and References fields.  # noqa: E501

        :return: The thread_id of this EmailPreview.  # noqa: E501
        :rtype: str
        """
        return self._thread_id

    @thread_id.setter
    def thread_id(self, thread_id):
        """Sets the thread_id of this EmailPreview.

        MailSlurp thread ID for email chain that enables lookup for In-Reply-To and References fields.  # noqa: E501

        :param thread_id: The thread_id of this EmailPreview.  # noqa: E501
        :type: str
        """

        self._thread_id = thread_id

    @property
    def message_id(self):
        """Gets the message_id of this EmailPreview.  # noqa: E501

        RFC 5322 Message-ID header value without angle brackets.  # noqa: E501

        :return: The message_id of this EmailPreview.  # noqa: E501
        :rtype: str
        """
        return self._message_id

    @message_id.setter
    def message_id(self, message_id):
        """Sets the message_id of this EmailPreview.

        RFC 5322 Message-ID header value without angle brackets.  # noqa: E501

        :param message_id: The message_id of this EmailPreview.  # noqa: E501
        :type: str
        """

        self._message_id = message_id

    @property
    def in_reply_to(self):
        """Gets the in_reply_to of this EmailPreview.  # noqa: E501

        Parsed value of In-Reply-To header. A Message-ID in a thread.  # noqa: E501

        :return: The in_reply_to of this EmailPreview.  # noqa: E501
        :rtype: str
        """
        return self._in_reply_to

    @in_reply_to.setter
    def in_reply_to(self, in_reply_to):
        """Sets the in_reply_to of this EmailPreview.

        Parsed value of In-Reply-To header. A Message-ID in a thread.  # noqa: E501

        :param in_reply_to: The in_reply_to of this EmailPreview.  # noqa: E501
        :type: str
        """

        self._in_reply_to = in_reply_to

    @property
    def sender(self):
        """Gets the sender of this EmailPreview.  # noqa: E501


        :return: The sender of this EmailPreview.  # noqa: E501
        :rtype: Sender
        """
        return self._sender

    @sender.setter
    def sender(self, sender):
        """Sets the sender of this EmailPreview.


        :param sender: The sender of this EmailPreview.  # noqa: E501
        :type: Sender
        """

        self._sender = sender

    @property
    def recipients(self):
        """Gets the recipients of this EmailPreview.  # noqa: E501


        :return: The recipients of this EmailPreview.  # noqa: E501
        :rtype: EmailRecipients
        """
        return self._recipients

    @recipients.setter
    def recipients(self, recipients):
        """Sets the recipients of this EmailPreview.


        :param recipients: The recipients of this EmailPreview.  # noqa: E501
        :type: EmailRecipients
        """

        self._recipients = recipients

    @property
    def favourite(self):
        """Gets the favourite of this EmailPreview.  # noqa: E501


        :return: The favourite of this EmailPreview.  # noqa: E501
        :rtype: bool
        """
        return self._favourite

    @favourite.setter
    def favourite(self, favourite):
        """Sets the favourite of this EmailPreview.


        :param favourite: The favourite of this EmailPreview.  # noqa: E501
        :type: bool
        """

        self._favourite = favourite

    @property
    def body_part_content_types(self):
        """Gets the body_part_content_types of this EmailPreview.  # noqa: E501


        :return: The body_part_content_types of this EmailPreview.  # noqa: E501
        :rtype: list[str]
        """
        return self._body_part_content_types

    @body_part_content_types.setter
    def body_part_content_types(self, body_part_content_types):
        """Sets the body_part_content_types of this EmailPreview.


        :param body_part_content_types: The body_part_content_types of this EmailPreview.  # noqa: E501
        :type: list[str]
        """

        self._body_part_content_types = body_part_content_types

    @property
    def plus_address(self):
        """Gets the plus_address of this EmailPreview.  # noqa: E501


        :return: The plus_address of this EmailPreview.  # noqa: E501
        :rtype: str
        """
        return self._plus_address

    @plus_address.setter
    def plus_address(self, plus_address):
        """Sets the plus_address of this EmailPreview.


        :param plus_address: The plus_address of this EmailPreview.  # noqa: E501
        :type: str
        """

        self._plus_address = plus_address

    @property
    def size_bytes(self):
        """Gets the size_bytes of this EmailPreview.  # noqa: E501


        :return: The size_bytes of this EmailPreview.  # noqa: E501
        :rtype: int
        """
        return self._size_bytes

    @size_bytes.setter
    def size_bytes(self, size_bytes):
        """Sets the size_bytes of this EmailPreview.


        :param size_bytes: The size_bytes of this EmailPreview.  # noqa: E501
        :type: int
        """

        self._size_bytes = size_bytes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailPreview):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EmailPreview):
            return True

        return self.to_dict() != other.to_dict()
